@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2015-06-19'; # DATE
-our $VERSION = '1.16'; # VERSION
+our $DATE = '2015-06-30'; # DATE
+our $VERSION = '1.17'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -471,19 +471,29 @@ sub action_subcommands {
 sub action_version {
     my ($self, $r) = @_;
 
-    my $meta = $r->{meta} = $self->get_meta($r, $self->url);
+    my @text;
 
-    [200, "OK",
-     join("",
-          $self->get_program_and_subcommand_name($r),
-          " version ", ($meta->{entity_v} // "?"),
-          ($meta->{entity_date} ? " ($meta->{entity_date})" : ''),
-          "\n",
-          "  ", __PACKAGE__,
-          " version ", ($Perinci::CmdLine::Lite::VERSION // "?"),
-          ($Perinci::CmdLine::Lite::DATE ?
-               " ($Perinci::CmdLine::Lite::DATE)":''),
-      )];
+    {
+        my $meta = $r->{meta} = $self->get_meta($r, $self->url);
+        push @text, $self->get_program_and_subcommand_name($r),
+            " version ", ($meta->{entity_v} // "?"),
+            ($meta->{entity_date} ? " ($meta->{entity_date})" : ''),
+            "\n";
+    }
+
+    for my $url (@{ $self->extra_urls_for_version // [] }) {
+        my $meta = $self->get_meta($r, $url);
+        push @text, "  $url version ", ($meta->{entity_v} // "?"),
+            ($meta->{entity_date} ? " ($meta->{entity_date})" : ''),
+            "\n";
+    }
+
+    push @text, "  ", __PACKAGE__,
+        " version ", ($Perinci::CmdLine::Lite::VERSION // "?"),
+        ($Perinci::CmdLine::Lite::DATE ?
+         " ($Perinci::CmdLine::Lite::DATE)":'');
+
+    [200, "OK", join("", @text), {"x.perinci.cmdline._skip_format"=>1}];
 }
 
 sub action_help {
@@ -565,7 +575,7 @@ Perinci::CmdLine::Lite - A lightweight Rinci/Riap-based command-line application
 
 =head1 VERSION
 
-This document describes version 1.16 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-06-19.
+This document describes version 1.17 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2015-06-30.
 
 =head1 SYNOPSIS
 
